==> ejc-sddjsorg-api-3.0.0-20211018.072306-27-sources.jar: com/ejianc/business/sddjsorg/vo/OrgApplyFileSetVO.java <==
package com.ejianc.business.sddjsorg.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
public class OrgApplyFileSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String name; // 档案资料名称
    private Boolean required; // 是否必须上传
    private java.lang.String memo; // 备注
    private Boolean inUse; // 是否启用
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
    private String checkTime; // 校验时间点：submit:提交时校验，supplement:补充信息保存时校验，file:归档时校验
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public Boolean getInUse() {
        return inUse;
    }

    public void setInUse(Boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211027.120225-109-sources.jar: com/ejianc/business/sddjsorg/vo/OrgApplyFileSetVO.java <==
package com.ejianc.business.sddjsorg.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
public class OrgApplyFileSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String name; // 档案资料名称
    private Boolean required; // 是否必须上传
    private java.lang.String memo; // 备注
    private Boolean inUse; // 是否启用
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录，decision：股东决策
    private String checkTime; // 校验时间点：submit:提交时校验，supplement:补充信息保存时校验，file:归档时校验
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public Boolean getInUse() {
        return inUse;
    }

    public void setInUse(Boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
}
